netapp_ontap.models.chassis_nodes_pcis_cards API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.chassis_nodes_pcis_cards`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ChassisNodesPcisCardsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ChassisNodesPcisCards object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `device: str GET POST PATCH`

    The description of the PCI card.

    Example: Intel Lewisburg series chipset SATA Controller

  `info: str GET POST PATCH`

    The info string from the device driver of the PCI card.

    Example: Additional Info: 0 (0xaaf00000) SHM2S86Q120GLM22NP FW1146 114473MB 512B/sect (SPG190108GW)

  `slot: str GET POST PATCH`

    The slot where the PCI card is placed. This can sometimes take the form of "6-1" to indicate slot and subslot.

    Example: 0